mailr24387 - /trunk/gui/components/free_file_format.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 02, 2014 - 09:22:
Author: bugman
Date: Wed Jul  2 09:22:04 2014
New Revision: 24387

URL: http://svn.gna.org/viewcvs/relax?rev=24387&view=rev
Log:
Fix for bug #22257, the freezing of the GUI after using the free file format 
window on Mac OS X.

This is reported at https://gna.org/bugs/?22257.

This is a recurring problem in Mac OS X as it cannot be tested in the relax 
test suite.  The problem
is with wxPython.  The modal dialogs, such as the free file format window, 
cannot be destroyed on
Mac OS X using wx.Dialog.Destroy() - this kills wxPython and hence kills 
relax.  The problem does
not exist on any other operating system.  To fix this, all 
wx.Dialog.Destroy() calls have been
replaced with wx.Dialog.Close().


Modified:
    trunk/gui/components/free_file_format.py

Modified: trunk/gui/components/free_file_format.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/gui/components/free_file_format.py?rev=24387&r1=24386&r2=24387&view=diff
==============================================================================
--- trunk/gui/components/free_file_format.py    (original)
+++ trunk/gui/components/free_file_format.py    Wed Jul  2 09:22:04 2014
@@ -675,8 +675,8 @@
         @type event:    wx event
         """
 
-        # Destroy the window.
-        self.Destroy()
+        # Close the window.
+        self.Close()
 
 
     def reset(self, event):
@@ -700,5 +700,5 @@
         # Execute the base class method.
         self._element.save(event)
 
-        # Destroy the window.
-        self.Destroy()
+        # Close the window.
+        self.Close()




Related Messages


Powered by MHonArc, Updated Wed Jul 02 09:40:05 2014